@@ -44,6 +44,7 @@ def get_content():
     return contents
 
 DOCUMENT_CLASS_KWARGS = dict(
-    contact_lines=CONTACT_LINES
+    contact_lines=CONTACT_LINES,
+    packages=['graphicx']
 )
 OUTPUT_NAME = f'{AUTHORS[0]} Professional CV'
