@@ -265,7 +265,7 @@ just adjust how you call print for the class. There is also a Python 3 course bu
 Financial modeling course which focuses on using Python and Excel to understand
 personal finance and valuation problems.
         """.strip(),
-        highlight_description='Python and Excel-based course',
+        highlight_description='senior capstone Python and Excel-based course',
         long_description="""
 This course covers the full financial modelling workflow using both Excel and Python. I will try to teach you
 how to build a model in general, all the way from concept and data collection to the result and visualization,
