@@ -4,8 +4,11 @@ from typing import List, Sequence, Optional, Union
 
 import pyexlatex as pl
 import pyexlatex.resume as lr
+import pyexlatex.graphics as lg
 from pyexlatex.models.item import ItemBase
 
+from derobertis_cv.plbuild.paths import images_path
+from derobertis_cv.pldata.constants.contact import STYLED_SITE
 from derobertis_cv.pldata.jobs import (
     get_professional_jobs,
     get_academic_jobs
@@ -72,6 +75,8 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             include_private=model.include_private_jobs,
         )
     ]
+    lr_academic_jobs = [job.to_pyexlatex_employment() for job in get_academic_jobs()]
+    lr_education = [edu.to_pyexlatex() for edu in get_education()]
 
     all_contents = {
         ResumeSection.RESEARCH_INTERESTS: pl.Section(
@@ -79,11 +84,11 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             title='Research Interests'
         ),
         ResumeSection.EDUCATION: lr.SpacedSection(
-            get_education(),
+            lr_education,
             title='Education'
         ),
         ResumeSection.ACADEMIC_EXPERIENCE: pl.Section(
-            get_academic_jobs(),
+            lr_academic_jobs,
             title='Academic Experience'
         ),
         ResumeSection.PROFESSIONAL_EXPERIENCE: pl.Section(
@@ -133,7 +138,11 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
         )
     }
 
-    selected_contents = []
+    selected_contents = [
+        pl.Raw(r'\vspace*{-3cm}\vbox{\hspace{13.9cm} \href{https://nickderobertis.com}{\includegraphics[width=3.85cm, height=4cm]{' + images_path('nick-derobertis.png') + '}}}'),
+        pl.Raw(r'\hspace{13.3cm} \parbox[r]{5cm}{\centering See more at ' + STYLED_SITE + '}'),
+        pl.VSpace(-0.6),
+    ]
     for section in model.sections:
         if isinstance(section, ResumeSection):
             selected_contents.append(all_contents[section])
