@@ -164,6 +164,7 @@ _SKILLS: List[SkillModel] = [
     MIGRATIONS_SKILL,
     HARDWARE_SKILL,
     IDE_SKILL,
+    VISUALIZATION_SKILL,
     SkillModel('SQL', 4, parents=(DATABASE_SKILL,), flexible_case=False),
     SkillModel('Redis', 4, parents=(DATABASE_SKILL,), flexible_case=False),
     SkillModel('Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False),
@@ -186,6 +187,10 @@ _SKILLS: List[SkillModel] = [
     SkillModel('IAM', 3, parents=(AWS_SKILL, COLLABORATION_SKILL), flexible_case=False),
     SkillModel('CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False),
     SkillModel('CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False),
+    SkillModel('ECS', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False),
+    SkillModel('CDK', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False),
+
+    SkillModel('Nginx', 3, parents=(SERVER_ADMIN_SKILL,), flexible_case=False),
 
     SkillModel('JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False),
 
@@ -220,8 +225,10 @@ _SKILLS: List[SkillModel] = [
     SkillModel('Flask', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('Django', 2, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('SQLAlchemy', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
+    SkillModel('FastAPI', 3, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False),
 
     SkillModel('Celery', 4, parents=ASYNC_FRAMEWORK_SKILLS, flexible_case=False),
+    SkillModel('Uvicorn', 3, parents=BE_WEB_FRAMEWORK_SKILLS + ASYNC_FRAMEWORK_SKILLS, flexible_case=False),
 
     SkillModel('Requests', 4, parents=WEB_SCRAPING_FRAMEWORK_SKILLS, flexible_case=False),
     SkillModel('Selenium', 4, parents=WEB_SCRAPING_FRAMEWORK_SKILLS, flexible_case=False),
